/*
* Copyright 1993-2006 NVIDIA Corporation.  All rights reserved.
*
* NOTICE TO USER:
*
* This source code is subject to NVIDIA ownership rights under U.S. and
* international Copyright laws.
*
* NVIDIA MAKES NO REPRESENTATION ABOUT THE SUITABILITY OF THIS SOURCE
* CODE FOR ANY PURPOSE.  IT IS PROVIDED "AS IS" WITHOUT EXPRESS OR
* IMPLIED WARRANTY OF ANY KIND.  NVIDIA DISCLAIMS ALL WARRANTIES WITH
* REGARD TO THIS SOURCE CODE, INCLUDING ALL IMPLIED WARRANTIES OF
* MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
* IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL,
* OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
* OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
* OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE
* OR PERFORMANCE OF THIS SOURCE CODE.
*
* U.S. Government End Users.  This source code is a "commercial item" as
* that term is defined at 48 C.F.R. 2.101 (OCT 1995), consisting  of
* "commercial computer software" and "commercial computer software
* documentation" as such terms are used in 48 C.F.R. 12.212 (SEPT 1995)
* and is provided to the U.S. Government only as a commercial end item.
* Consistent with 48 C.F.R.12.212 and 48 C.F.R. 227.7202-1 through
* 227.7202-4 (JUNE 1995), all U.S. Government End Users acquire the
* source code with only those rights set forth herein.
*/

/* This sample is a templatized version of the template project.
* It also shows how to correctly templatize dynamically allocated shared
* memory arrays.
* Host code.
*/

// includes, system
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

// includes, project
#include <cutil.h>
#include "config.h"
// includes, kernels
#include "doubleTest_kernel.cu"


////////////////////////////////////////////////////////////////////////////////
// Program main
////////////////////////////////////////////////////////////////////////////////
int
main( int argc, char** argv) 
{
	ImgType* imageDevice = NULL;
    CUDA_SAFE_CALL(cudaMalloc((void**)&imageDevice,ImageWidth*ImageHeight*3*sizeof(ImgType)));

	ColorType a = 0.1;
	//start the kernel
	dim3 block(8, 8, 1);
	dim3 grid(ImageWidth/8, ImageHeight/8, 1);
	simpleKernel<<<grid,block>>>(imageDevice,ImageWidth,a);
	
	//wait for the kernel to finish
	CUDA_SAFE_CALL(cudaThreadSynchronize());

	ImgType* image = new ImgType[ImageWidth*ImageHeight*3];
	CUDA_SAFE_CALL(cudaMemcpy(image,imageDevice,ImageWidth*ImageHeight*3*sizeof(ImgType),cudaMemcpyDeviceToHost));
	CUDA_SAFE_CALL(cudaFree(imageDevice));
	//save the image
	CUT_SAFE_CALL( cutSavePPMub( "result.pgm", image,ImageWidth , ImageHeight));
	delete[] image;

    CUT_EXIT(argc, argv);
}

